<?php

@require_once DIR_FS_ADMIN . DIR_WS_CLASSES . 'plugin.php';
class eo_plugin extends plugin {
	public function getVersion() { return '4.1.1'; }
	public function getUniqueKey() { return 'EO'; }
	public function getUniqueName() { return 'Edit Orders'; }
	public function getDescription() { return 'Settings for Edit Orders'; }
	public function getNewFiles() {
		return array(
			DIR_FS_ADMIN . 'edit_orders.php',
			DIR_FS_ADMIN . DIR_WS_INCLUDES . 'edit_orders.css',
			DIR_FS_ADMIN . DIR_WS_CLASSES . 'attributes.php',
			DIR_FS_ADMIN . DIR_WS_INCLUDES . 'extra_configures/edit_orders.php',
			DIR_FS_ADMIN . DIR_WS_FUNCTIONS . 'extra_functions/edit_orders_functions.php',
			DIR_FS_ADMIN . DIR_WS_LANGUAGES . 'english/edit_orders.php',
			DIR_FS_ADMIN . DIR_WS_LANGUAGES . 'english/extra_definitions/edit_orders.php',
			DIR_FS_ADMIN . DIR_WS_LANGUAGES . 'english/images/buttons/button_add_product.gif',
			DIR_FS_ADMIN . DIR_WS_IMAGES . 'icon_billing.png',
			DIR_FS_ADMIN . DIR_WS_IMAGES . 'icon_comment_add.png',
			DIR_FS_ADMIN . DIR_WS_IMAGES . 'icon_customers.png',
			DIR_FS_ADMIN . DIR_WS_IMAGES . 'icon_shipping.png',
			DIR_FS_ADMIN . DIR_WS_IMAGES . 'icon_track_add.png',
			DIR_FS_ADMIN . DIR_WS_IMAGES . 'icon_details.gif',
			DIR_FS_ADMIN . DIR_WS_IMAGES . 'icon_edit.gif',
			DIR_FS_ADMIN . DIR_WS_IMAGES . 'icon_invoice.gif'
		);
	}
	public function getObsoleteFiles() {
		return array(
			DIR_FS_ADMIN . DIR_WS_LANGUAGES . 'english/plugin.php',
			DIR_FS_ADMIN . DIR_WS_FUNCTIONS . 'extra_functions/common_orders_functions.php',
			DIR_FS_ADMIN . DIR_WS_FUNCTIONS . 'init_includes/init_eo_config.php',
			DIR_FS_ADMIN . DIR_WS_INCLUDES . 'extra_datafiles/edit_orders_defines.php'
		);
	}
	public function handleFileChanges($install = true) {
		$success = true;

		if($install) {
			// Scan for the presence of these modules and fix some potential issues
			if(defined('SO_VERSION') && version_compare(SO_VERSION, '4.0.5', '<=')) {
				$success = $success && $this->replaceInFile(
					DIR_FS_ADMIN . FILENAME_ORDERS . '.php',
					'/FILENAME_ORDER_EDIT/',
					'FILENAME_EDIT_ORDERS'
				);
			}
			if(defined('FILENAME_NEW_ORDER') && !defined('ANO_VERSION')) {
				$success = $success && $this->replaceInFile(
					DIR_FS_ADMIN . FILENAME_ORDERS . '.php',
					'/FILENAME_ORDER_EDIT/',
					'FILENAME_EDIT_ORDERS'
				);
				$success = $success && $this->replaceInFile(
					DIR_FS_ADMIN . FILENAME_NEW_ORDER . '.php',
					'/FILENAME_ORDER_EDIT/',
					'FILENAME_EDIT_ORDERS'
				);
			}
		}

		return $success;
	}
	public function handleUpgradeFrom($version) {
		$success = true;
		switch($version) {
			case '4.0.2': // 4.0.3 and 4.0.4 left this set to 4.0.2
			case '4.1':
			case '4.1.1':
				// Remove the obsolete "Shipping Tax" configuration option
				$this->removeConfigurationOption('SHIPPING_TAX');

				// We changed a definition related to the edit orders admin page
				if(function_exists('zen_deregister_admin_pages') && zen_page_key_exists('editOrders')) zen_deregister_admin_pages('editOrders');
				if(function_exists('zen_deregister_admin_pages') && zen_page_key_exists('configEditOrders')) zen_deregister_admin_pages('configEditOrders');

				break;
			default:
				break;
		}
		return $success;
	}
	public function handleAdminMenuChanges($install = true) {
		global $db;

		$success = true;
		if($install) {
			if(!zen_page_key_exists('editOrders')) {
				// Get the sort order
				$page_sort_query = "SELECT MAX(sort_order) as max_sort FROM `". TABLE_ADMIN_PAGES ."` WHERE menu_key='customers'";
				$page_sort = $db->Execute($page_sort_query);
				$page_sort = $page_sort->fields['max_sort'] + 1;

				// Register the administrative pages
				zen_register_admin_page('editOrders', 'BOX_CONFIGURATION_EDIT_ORDERS',
				'FILENAME_EDIT_ORDERS', '', 'customers', 'N', $page_sort);
			}
			if(!zen_page_key_exists('configEditOrders')) {
				// Get the sort order
				$page_sort_query = "SELECT MAX(sort_order) as max_sort FROM `". TABLE_ADMIN_PAGES ."` WHERE menu_key='configuration'";
				$page_sort = $db->Execute($page_sort_query);
				$page_sort = $page_sort->fields['max_sort'] + 1;

				// Register the administrative pages
				zen_register_admin_page('configEditOrders', 'BOX_CONFIGURATION_EDIT_ORDERS',
				'FILENAME_CONFIGURATION', 'gID=' . $this->getConfigurationGroupId(),
				'configuration', 'Y', $page_sort);
			}
			if(!zen_page_key_exists('editOrders') || !zen_page_key_exists('configEditOrders')) {
				$success = false;
			}
		}
		else {
			if(zen_page_key_exists('editOrders')) zen_deregister_admin_pages('editOrders');
			if(zen_page_key_exists('configEditOrders')) zen_deregister_admin_pages('configEditOrders');
			if(zen_page_key_exists('editOrders') || zen_page_key_exists('configEditOrders')) {
				$success = false;
			}
		}

		return $success;
	}
}